AutoArchive._application._action — AutoArchive Developer Manual (ver. 2.0.6)

# AutoArchive._application._action

## Modules

### action_result

class AutoArchive._application._action.action_result.ActionResult(componentUi)

  Bases: `object`

  computeReturnValue(executeResult: bool) → bool
  set(result: Successful, Issues, Failed)
  startObservingUiMessages()
  stopObservingUiMessages()
  ActionResults = Successful, Issues, Failed

    Enumerates statuses how a backup operation can finish.

  property result: Successful, Issues, Failed

### action

class AutoArchive._application._action.action.Action(actionResult: ActionResult)

  Bases: `object`

  execute() → bool
  abstractmethod executeAction_() → bool
  handleResult_(actionResult: ActionResult) → None